@@ -3,8 +3,9 @@ use strict;
 use warnings;
 use base qw(Exporter);
 
-our @EXPORT_OK = qw(check_config_script check_prebuilt_binaries check_src_build find_SDL_dir find_file sed_inplace);
+our @EXPORT_OK = qw(check_config_script check_prebuilt_binaries check_src_build find_SDL_dir find_file check_header sed_inplace);
 use Config;
+use ExtUtils::CBuilder;
 use File::Spec::Functions qw(splitdir catdir splitpath catpath rel2abs);
 use File::Find qw(find);
 use File::Copy qw(cp);
@@ -175,13 +176,16 @@ my $source_packs = [
           'http://froggs.de/libsdl/SDL_Pango-0.1.2.tar.gz',
         ],
         sha1sum  => 'c30f2941d476d9362850a150d29cb4a93730af68',
-        patches => [ 'SDL_Pango-0.1.2-API-adds.patch' ],
+        patches => [
+          'SDL_Pango-0.1.2-API-adds.1.patch',
+          'SDL_Pango-0.1.2-API-adds.2.patch',
+        ],
       },
     ],
   },
 ## another src build set (without PANGO SUPPORT)
   {
-    title   => "Source code build: SDL-1.2.14 & co. (NO PANGO)\n" .
+    title   => "Source code build: SDL-1.2.14 & co. (no PANGO, but TTF)\n" .
                "\tbuilds: SDL, SDL_(image|mixer|ttf|net|gfx)\n" .
                "\tneeds preinstalled: freetype2-devel",
     prereqs => {
@@ -293,6 +297,108 @@ my $source_packs = [
       },
     ],
   },
+## another src build set (without PANGO/TTF SUPPORT)
+  {
+    title   => "Source code build: SDL-1.2.14 & co. (no PANGO, no TTF)\n" .
+               "\tbuilds: SDL, SDL_(image|mixer|net|gfx)",
+    prereqs => {
+        libs => [
+          'pthread',  # SDL
+        ]
+    },
+    members     => [
+      {
+        pack => 'SDL',
+        dirname => 'SDL-1.2.14',
+        url => [
+          'http://www.libsdl.org/release/SDL-1.2.14.tar.gz',
+          'http://froggs.de/libsdl/SDL-1.2.14.tar.gz',
+        ],
+        sha1sum  => 'ba625b4b404589b97e92d7acd165992debe576dd',
+        patches => [
+          'test1.patch',
+        ],
+      },
+      {
+        pack => 'zlib',
+        dirname => 'zlib-1.2.5',
+        url => [
+          'http://zlib.net/zlib-1.2.5.tar.gz',
+          'http://froggs.de/libz/zlib-1.2.5.tar.gz',
+        ],
+        sha1sum  => '8e8b93fa5eb80df1afe5422309dca42964562d7e',
+      },
+      {
+        pack => 'jpeg',
+        dirname => 'jpeg-8a',
+        url => [
+          'http://www.ijg.org/files/jpegsrc.v8a.tar.gz',
+          'http://froggs.de/libjpeg/jpegsrc.v8a.tar.gz',
+        ],
+        sha1sum  => '78077fb22f0b526a506c21199fbca941d5c671a9',
+        patches => [ 'jpeg-8a_cygwin.patch' ],
+      },
+      {
+        pack => 'tiff',
+        dirname => 'tiff-3.9.1',
+        url => [
+          'http://froggs.de/libtiff/tiff-3.9.1.tar.gz',
+          'ftp://ftp.remotesensing.org/pub/libtiff/tiff-3.9.1.tar.gz',
+        ],
+        sha1sum  => '675ad1977023a89201b80cd5cd4abadea7ba0897',
+        patches => [ ],
+      },
+      {
+        pack => 'libpng',
+        dirname => 'libpng-1.4.1',
+        url => [
+          'http://downloads.sourceforge.net/libpng/libpng-1.4.1.tar.gz',
+          'http://froggs.de/libpng/libpng-1.4.1.tar.gz',
+        ],
+        sha1sum  => '7a3488f5844068d67074f2507dd8a7ed9c69ff04',
+      },
+      {
+        pack => 'SDL_image',
+        dirname => 'SDL_image-1.2.10',
+        url => [
+          'http://www.libsdl.org/projects/SDL_image/release/SDL_image-1.2.10.tar.gz',
+          'http://froggs.de/libsdl/SDL_image-1.2.10.tar.gz',
+        ],
+        sha1sum  => '6bae71fdfd795c3dbf39f6c7c0cf8b212914ef97',
+        patches => [ ],
+      },
+      {
+        pack => 'SDL_mixer',
+        dirname => 'SDL_mixer-1.2.11',
+        url => [
+          'http://www.libsdl.org/projects/SDL_mixer/release/SDL_mixer-1.2.11.tar.gz',
+          'http://froggs.de/libsdl/SDL_mixer-1.2.11.tar.gz',
+        ],
+        sha1sum  => 'ef5d45160babeb51eafa7e4019cec38324ee1a5d',
+        patches => [ ],
+      },
+      {
+        pack => 'SDL_net',
+        dirname => 'SDL_net-1.2.7',
+        url => [
+          'http://www.libsdl.org/projects/SDL_net/release/SDL_net-1.2.7.tar.gz',
+          'http://froggs.de/libsdl/SDL_net-1.2.7.tar.gz',
+        ],
+        sha1sum  => 'b46c7e3221621cc34fec1238f1b5f0ce8972274d',
+        patches => [ ],
+      },
+      {
+        pack => 'SDL_gfx',
+        dirname => 'SDL_gfx-2.0.20',
+        url => [
+          'http://www.ferzkopp.net/Software/SDL_gfx-2.0/SDL_gfx-2.0.20.tar.gz',
+          'http://froggs.de/libsdl/SDL_gfx-2.0.20.tar.gz',
+        ],
+        sha1sum  => '077f7e64376c50a424ef11a27de2aea83bda3f78',
+        patches => [ ],
+      },
+    ],
+  },
 ## another src build set (all from sources)
   {
     title   => "Source code build: SDL-1.2.14 & co. + all prereq. libraries\n" .
@@ -559,6 +665,35 @@ sub find_SDL_dir {
   }
 }
 
+sub check_header {
+  my ($cflags, @header) = @_;
+  print STDERR "Testing header(s): " . join(', ', @header) . "\n";
+  my $cb = ExtUtils::CBuilder->new(quiet => 1);
+  my ($fs, $src) = File::Temp->tempfile('XXXXaa', SUFFIX => '.c', UNLINK => 1);
+  my $inc = '';
+  $inc .= "#include <$_>\n" for @header;  
+  syswrite($fs, <<MARKER); # write test source code
+#if defined(_WIN32) && !defined(__CYGWIN__)
+#include <stdio.h>
+/* GL/gl.h on Win32 requires windows.h being included before */
+#include <windows.h>
+#endif
+$inc
+int demofunc(void) { return 0; }
+
+MARKER
+  close($fs);
+  my $obj = eval { $cb->compile( source => $src, extra_compiler_flags => $cflags); };
+  if($obj) {
+    unlink $obj;
+    return 1;
+  }
+  else {
+    print STDERR "###TEST FAILED### for: " . join(', ', @header) . "\n";
+    return 0;
+  }
+}
+
 sub sed_inplace {
   # we expect to be called like this:
   # sed_inplace("filename.txt", 's/0x([0-9]*)/n=$1/g');
